# Changes

## v0.2.3 - 2025-04-18

- Add HTTP endpoint to revoke all tokens for a user.

## v0.2.2 - 2025-04-14

- Set initial focus to `sub` input in authorization form.

## v0.2.1 - 2025-03-20

- Add required `httpx` production dependency.
